############################################################
# R script for illustrating the analysis of multiplex data #
############################################################

# Load RSiena commands:
library(RSiena)

# Set working directory to where the data are:
setwd("<set to where the data are>")
list.files()

# Read the data sets for the assignment:
friendship.net1 <- as.matrix(read.table("MBA-Friendship1.txt"))
friendship.net2 <- as.matrix(read.table("MBA-Friendship2.txt"))
advice.net1 <- as.matrix(read.table("MBA-Advice1.txt"))
advice.net2 <- as.matrix(read.table("MBA-Advice2.txt"))

# Identify dependent variables for the analysis;
advice <- sienaNet(array(c(advice.net1,advice.net2), dim=c(75,75,2)))
friendship <- sienaNet(array(c(friendship.net1, friendship.net2), dim=c(75,75,2)))

# Combine data for the analysis:
ExampleData <- sienaDataCreate(friendship,advice)

# Get effects table for model specification:
ExampleEffects <- getEffects(ExampleData)

# Generate initial descriptive outputfile:
print01Report(ExampleData,ExampleEffects, modelname="Multiplex-illustration")

# Take a look at the generated output file "Multiplex-illustration.out"
# to see how RSiena interpreted the directives provided.
#
# The specifically "multiplex" effects as given in the manual can be found
# by inspecting:
fix(ExampleEffects)
# 
# From here on proceed "as usual", e.g., as follows:

# transitivity and 3-cycle effects for the evolution of advice seeking,
# and that of friendship:
ExampleEffects <- includeEffects(ExampleEffects,transTrip,cycle3,name="advice")
ExampleEffects <- includeEffects(ExampleEffects,transTrip,cycle3,name="friendship")

# Include main effects of the dependent networks on each other's evolution:
ExampleEffects <- includeEffects(ExampleEffects,crprod,name="advice",interaction1="friendship")
ExampleEffects <- includeEffects(ExampleEffects,crprod,name="friendship",interaction1="advice")

# Create model object:
ExampleModel <- sienaModelCreate(projname="Multiplex-illustration",useStdInits=TRUE)

# Estimate model:
ExampleResults <- siena07(ExampleModel,data=ExampleData,effects=ExampleEffects,batch=FALSE,verbose=FALSE)

# Results indicate effect of advice on friendship. What does it mean?
# Evaluation function effects model both maintenance of old ties and creation of new ones.
#
# Estimate the corresponding endowment and creation effects instead to test whether the
# found effect is one of maintaining exisiting friendship ties (which would would be
# stabilised by advice seeking) or an effect of creating new ties based on advice seeking.

ExampleEffects <- includeEffects(ExampleEffects,crprod,
   name="friendship",interaction1="advice",type="endow")
ExampleEffects <- includeEffects(ExampleEffects,crprod,
   name="friendship",interaction1="advice",type="creation")
ExampleEffects <- includeEffects(ExampleEffects,crprod,
   name="friendship",interaction1="advice",type="eval",include=FALSE)

# For symmetry reasoning, do the same for the 'opposite effect' of friendship on
# advice seeking:   
   
ExampleEffects <- includeEffects(ExampleEffects,crprod,
   name="advice",interaction1="friendship",type="endow")
ExampleEffects <- includeEffects(ExampleEffects,crprod,
   name="advice",interaction1="friendship",type="creation")
ExampleEffects <- includeEffects(ExampleEffects,crprod,
   name="advice",interaction1="friendship",type="eval",include=FALSE)
   
# Now estimate the model:
ExampleResults <- siena07(ExampleModel,data=ExampleData,effects=ExampleEffects,batch=FALSE,verbose=FALSE)
ExampleResults

ExampleResults

save.image("multiplex-results.RData")

# What can be seen is that there is a significant creation (and no endowment) effect
# of friendship on advice seeking, and a significant endowment (but no creation) effect
# of advice seeking on friendship.
#
# Bottomline: Friendship leads to new advice seeking; advice seeking stabilises existing friendship.

